@@ -169,6 +169,15 @@ class DocumentEvolution(object):
         assert doc.get("format") == "Dashboard Bundle Format 1.4"
         doc["format"] = "Dashboard Bundle Format 1.5"
 
+    def _evolution_from_1_5_to_1_6(doc):
+        """
+        Evolution method for 1.5 -> 1.6:
+
+            * No changes required
+        """
+        assert doc.get("format") == "Dashboard Bundle Format 1.5"
+        doc["format"] = "Dashboard Bundle Format 1.6"
+
     EVOLUTION_PATH = [
         ("Dashboard Bundle Format 1.0",
          "Dashboard Bundle Format 1.0.1",
@@ -188,4 +197,7 @@ class DocumentEvolution(object):
         ("Dashboard Bundle Format 1.4",
          "Dashboard Bundle Format 1.5",
          _evolution_from_1_4_to_1_5),
+        ("Dashboard Bundle Format 1.5",
+         "Dashboard Bundle Format 1.6",
+         _evolution_from_1_5_to_1_6),
     ]
