@@ -228,6 +228,9 @@ class DocumentIORegressionTests(TestWithScenarios, TestCase):
         ('everything_in_one_bundle_1_5', {
             'filename': 'everything_in_one_bundle_1.5.json'
         }),
+        ('everything_in_one_bundle_1_6', {
+            'filename': 'everything_in_one_bundle_1.6.json'
+        }),
     ]
 
     def test_load_document(self):
@@ -286,7 +289,7 @@ class DocumentEvolutionTests_1_0_to_1_0_1(TestCase):
         self.assertEqual(DocumentIO.check(self.doc),
                          "Dashboard Bundle Format 1.0.1")
 
-    def test_evoloved_document_is_what_we_expect(self):
+    def test_evolved_document_is_what_we_expect(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         fmt, expected = DocumentIO.load(
             resource_stream('linaro_dashboard_bundle',
@@ -333,7 +336,7 @@ class DocumentEvolutionTests_1_0_1_to_1_1(TestCase):
         self.assertEqual(DocumentIO.check(self.doc),
                          "Dashboard Bundle Format 1.1")
 
-    def test_evoloved_document_is_what_we_expect(self):
+    def test_evolved_document_is_what_we_expect(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         fmt, evolved_doc = DocumentIO.load(
             resource_stream('linaro_dashboard_bundle',
@@ -366,7 +369,7 @@ class DocumentEvolutionTests_1_1_to_1_2(TestCase):
         self.assertEqual(DocumentIO.check(self.doc),
                          "Dashboard Bundle Format 1.2")
 
-    def test_evoloved_document_is_what_we_expect(self):
+    def test_evolved_document_is_what_we_expect(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         fmt, evolved_doc = DocumentIO.load(
             resource_stream('linaro_dashboard_bundle',
@@ -399,7 +402,7 @@ class DocumentEvolutionTests_1_2_to_1_3(TestCase):
         self.assertEqual(DocumentIO.check(self.doc),
                          "Dashboard Bundle Format 1.3")
 
-    def test_evoloved_document_is_what_we_expect(self):
+    def test_evolved_document_is_what_we_expect(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         fmt, evolved_doc = DocumentIO.load(
             resource_stream('linaro_dashboard_bundle',
@@ -432,7 +435,7 @@ class DocumentEvolutionTests_1_3_to_1_4(TestCase):
         self.assertEqual(DocumentIO.check(self.doc),
                          "Dashboard Bundle Format 1.4")
 
-    def test_evoloved_document_is_what_we_expect(self):
+    def test_evolved_document_is_what_we_expect(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         fmt, evolved_doc = DocumentIO.load(
             resource_stream('linaro_dashboard_bundle',
@@ -458,17 +461,50 @@ class DocumentEvolutionTests_1_4_to_1_5(TestCase):
     def test_evolved_document_is_latest_format(self):
         self.assertFalse(DocumentEvolution.is_latest(self.doc))
         DocumentEvolution.evolve_document(self.doc, one_step=True)
-        self.assertTrue(DocumentEvolution.is_latest(self.doc))
+        self.assertFalse(DocumentEvolution.is_latest(self.doc))
 
     def test_evolved_document_is_valid(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         self.assertEqual(DocumentIO.check(self.doc),
                          "Dashboard Bundle Format 1.5")
 
-    def test_evoloved_document_is_what_we_expect(self):
+    def test_evolved_document_is_what_we_expect(self):
         DocumentEvolution.evolve_document(self.doc, one_step=True)
         fmt, evolved_doc = DocumentIO.load(
             resource_stream('linaro_dashboard_bundle',
                             'test_documents/evolution_1.5.json'),
             retain_order=False)
         self.assertEqual(self.doc, evolved_doc)
+
+
+class DocumentEvolutionTests_1_5_to_1_6(TestCase):
+
+    def setUp(self):
+        super(DocumentEvolutionTests_1_5_to_1_6, self).setUp()
+        self.fmt, self.doc = DocumentIO.load(
+            resource_stream('linaro_dashboard_bundle',
+                            'test_documents/evolution_1.5.json'),
+            retain_order=False)
+
+    def test_format_is_changed(self):
+        self.assertEqual(self.doc["format"], "Dashboard Bundle Format 1.5")
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertEqual(self.doc["format"], "Dashboard Bundle Format 1.6")
+
+    def test_evolved_document_is_latest_format(self):
+        self.assertFalse(DocumentEvolution.is_latest(self.doc))
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertTrue(DocumentEvolution.is_latest(self.doc))
+
+    def test_evolved_document_is_valid(self):
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        self.assertEqual(DocumentIO.check(self.doc),
+                         "Dashboard Bundle Format 1.6")
+
+    def test_evolved_document_is_what_we_expect(self):
+        DocumentEvolution.evolve_document(self.doc, one_step=True)
+        fmt, evolved_doc = DocumentIO.load(
+            resource_stream('linaro_dashboard_bundle',
+                            'test_documents/evolution_1.6.json'),
+            retain_order=False)
+        self.assertEqual(self.doc, evolved_doc)
